@@ -445,6 +445,7 @@ void ok_input (GtkTreeView * treeview)
     }
 
 
+    TRACE("at input ok,tree_details->input=%d (%d,%d)",tree_details->input,RUN_DOUBLE_CLICK,RUN_INPUT);
     switch (tree_details->input)
     {
 	default:
@@ -538,7 +539,11 @@ void ok_input (GtkTreeView * treeview)
 	      oldname=NULL;
 	      g_free(newname);
 	      newname=NULL;
-    	      reload_book(treeview); 
+	      if (strcmp(tree_details->argv[0],"xfbook")==0 || strcmp(tree_details->argv[0],"xfbook4")==0){
+		g_free(tree_details->argv[1]);
+		tree_details->argv[1] = g_strdup(bookfile);
+	      }
+   	      reload_book(treeview); 
 	    }
 	    return;
 	case WORKDIR_INPUT:
@@ -607,6 +612,7 @@ void ok_input (GtkTreeView * treeview)
 		gboolean in_terminal, remember, hold;
 		GtkWidget *check;
 		gchar *in_cmd;
+		TRACE("at RUN_INPUT");
 		check = WIDGET("checkbutton1");
 		in_terminal = gtk_toggle_button_get_active((GtkToggleButton *) check);
 		check = WIDGET("checkbutton3");
@@ -642,6 +648,7 @@ void ok_input (GtkTreeView * treeview)
 		    remember = gtk_toggle_button_get_active((GtkToggleButton *) check);
 		    en = get_selected_entry( &iter);
 		}
+		TRACE("at input ok on_run %s",in_cmd);
 		if(on_run(in_cmd, en, in_terminal, remember, TRUE, hold))
 		{
 		    print_status("xfce/info", _("Executing"), " ", in_cmd, NULL);
