@@ -56,6 +56,10 @@
 #endif
 #endif
 
+/*#define THIS_IS_NOT_PART_OF_4_2*/
+#ifdef THIS_IS_NOT_PART_OF_4_2
+#include "iconview.c"
+#endif /*THIS_IS_NOT_PART_OF_4_2*/ 
 
 G_MODULE_EXPORT
 SessionClient *session_client;
@@ -598,6 +602,11 @@ int main(int argc, char *argv[])
    gtk_widget_grab_focus((GtkWidget *) treeview);
       
    tree_details->comm=0;
+
+#ifdef THIS_IS_NOT_PART_OF_4_2
+    create_test_window();
+#endif /*THIS_IS_NOT_PART_OF_4_2*/ 
+
    gtk_main();
    mcs_stop_watch(); 
 
